@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #ifndef WARNINGS_CONFIG_H
@@ -22,8 +17,8 @@ class Warnings_Config : public QWidget, public KonviSettingsPage, private Ui::Wa
     Q_OBJECT
 
     public:
-        explicit Warnings_Config( QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = 0 );
-        ~Warnings_Config() override;
+        explicit Warnings_Config( QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags fl = {} );
+        ~Warnings_Config();
 
         void restorePageToDefaults() override;
         void saveSettings() override;
@@ -34,13 +29,16 @@ class Warnings_Config : public QWidget, public KonviSettingsPage, private Ui::Wa
     public Q_SLOTS:
         virtual void languageChange();
 
-    protected:
-        QString currentWarningsChecked(); // for hasChanged()
-
-        QString m_oldWarningsChecked;     // for hasChanged()
-
     Q_SIGNALS:
         void modified();
+
+    private:
+        QString currentWarningsChecked() const; // for hasChanged()
+
+    private:
+        QString m_oldWarningsChecked;     // for hasChanged()
+
+        Q_DISABLE_COPY(Warnings_Config)
 };
 
 #endif // WARNINGS_CONFIG_H
